@@ -1,4 +1,4 @@
-from coder import Coder
+from AGCoder import Coder
 from query_where import AGQueryWhere
 
 
